@@ -125,16 +125,21 @@ class ValidatorService:
                             errors, field, 'active_url', {'_attribute': field}
                         )
                 elif r.startswith('after:'):
+                    ref_field = r.split(':')[1]
                     try:
-                        input_date = datetime.strptime(value, '%Y-%m-%d').date()
-                        after_date = datetime.strptime(r.split(':')[1], '%Y-%m-%d').date()
-                        if input_date <= after_date:
-                            ValidatorService._add_error(
-                                errors, field, 'after', {'_attribute': field, 'date': r.split(':')[1]}
-                            )
+                        if ref_field in data:
+                            ref_value = data.get(ref_field)
+                            if value and ref_value:
+                                input_date = datetime.strptime(value, '%Y-%m-%d').date()
+                                ref_date = datetime.strptime(ref_value, '%Y-%m-%d').date()
+                                if input_date <= ref_date:
+                                    ValidatorService._add_error(
+                                        errors, field, 'after', {'_attribute': field, 'date': ref_field}
+                                    )
+                        
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'after', {'_attribute': field, 'date': r.split(':')[1]}
+                            errors, field, 'after', {'_attribute': field, 'date': ref_field}
                         )
                 elif r.startswith('after_or_equal:'):
                     ref_field = r.split(':')[1]
@@ -179,28 +184,38 @@ class ValidatorService:
                             errors, field, 'min_array', {'_attribute': field, '_min': 1}
                         )
                 elif r.startswith('before:'):
+                    ref_field = r.split(':')[1]
                     try:
-                        input_date = datetime.strptime(value, '%Y-%m-%d').date()
-                        before_date = datetime.strptime(r.split(':')[1], '%Y-%m-%d').date()
-                        if input_date >= before_date:
-                            ValidatorService._add_error(
-                                errors, field, 'before', {'_attribute': field, 'date': r.split(':')[1]}
-                            )
+                        if ref_field in data:
+                            ref_value = data.get(ref_field)
+                            if value and ref_value:
+                                input_date = datetime.strptime(value, '%Y-%m-%d').date()
+                                ref_date = datetime.strptime(ref_value, '%Y-%m-%d').date()
+                                if input_date >= ref_date:
+                                    ValidatorService._add_error(
+                                        errors, field, 'before', {'_attribute': field, 'date': ref_field}
+                                    )
+                        
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'before', {'_attribute': field, 'date': r.split(':')[1]}
+                            errors, field, 'before', {'_attribute': field, 'date': ref_field}
                         )
                 elif r.startswith('before_or_equal:'):
+                    ref_field = r.split(':')[1]
                     try:
-                        input_date = datetime.strptime(value, '%Y-%m-%d').date()
-                        before_date = datetime.strptime(r.split(':')[1], '%Y-%m-%d').date()
-                        if input_date > before_date:
-                            ValidatorService._add_error(
-                                errors, field, 'before_or_equal', {'_attribute': field, 'date': r.split(':')[1]}
-                            )
+                        if ref_field in data:
+                            ref_value = data.get(ref_field)
+                            if value and ref_value:
+                                input_date = datetime.strptime(value, '%Y-%m-%d').date()
+                                ref_date = datetime.strptime(ref_value, '%Y-%m-%d').date()
+                                if input_date > ref_date:
+                                    ValidatorService._add_error(
+                                        errors, field, 'before_or_equal', {'_attribute': field, 'date': ref_field}
+                                    )
+                        
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'before_or_equal', {'_attribute': field, 'date': r.split(':')[1]}
+                            errors, field, 'before_or_equal', {'_attribute': field, 'date': ref_field}
                         )
                 elif r.startswith('between:'):
                     min_val, max_val = map(int, r.split(':')[1].split(','))
@@ -317,6 +332,34 @@ class ValidatorService:
                         ValidatorService._add_error(
                             errors, field, 'exists', {'_attribute': field, '_error': str(e)}
                         )
+                elif r.startswith('not_exist:') or r.startswith('not_exists:'):
+                    try:
+                        parts = r.split(":", 1)[1].split(',')
+                        if len(parts) != 2:
+                            ValidatorService._add_error(
+                                errors, field, 'not_exist', {'_attribute': field}
+                            )
+                            continue
+
+                        table_name, column = parts
+                        if ValidatorService._is_empty(value):
+                            continue
+
+                        if not ValidatorService.table_exists(table_name):
+                            ValidatorService._add_error(
+                                errors, field, 'not_exist', {'_attribute': field, '_values': "Table Not Found"}
+                            )
+                            continue
+
+                        if ValidatorService.record_exists(table_name, column, value):
+                            ValidatorService._add_error(
+                                errors, field, 'not_exist', {'_attribute': field}
+                            )
+
+                    except ValueError as e:
+                        ValidatorService._add_error(
+                            errors, field, 'not_exist', {'_attribute': field, '_error': str(e)}
+                        )
 
                 elif r == 'file':
                     if not hasattr(value, 'file'):
@@ -333,42 +376,42 @@ class ValidatorService:
                         if isinstance(value, (int, float)):
                             if value <= float(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'gt_numeric', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'gt_numeric', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, str):
                             if len(value) <= int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'gt_string', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'gt_string', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, list):
                             if len(value) <= int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'gt_array', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'gt_array', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'gt', {'_attribute': field, '_value': r.split(':')[1]}
+                            errors, field, 'gt', {'_attribute': field, 'value': r.split(':')[1]}
                         )
                 elif r.startswith('gte:'):
                     try:
                         if isinstance(value, (int, float)):
                             if value < float(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'gte_numeric', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'gte_numeric', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, str):
                             if len(value) < int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'gte_string', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'gte_string', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, list):
                             if len(value) < int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'gte_array', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'gte_array', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'gte', {'_attribute': field, '_value': r.split(':')[1]}
+                            errors, field, 'gte', {'_attribute': field, 'value': r.split(':')[1]}
                         )
                 elif r == 'image':
                     if not hasattr(value, 'image'):
@@ -428,42 +471,42 @@ class ValidatorService:
                         if isinstance(value, (int, float)):
                             if value >= float(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'lt_numeric', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'lt_numeric', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, str):
                             if len(value) >= int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'lt_string', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'lt_string', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, list):
                             if len(value) >= int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'lt_array', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'lt_array', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'lt', {'_attribute': field, '_value': r.split(':')[1]}
+                            errors, field, 'lt', {'_attribute': field, 'value': r.split(':')[1]}
                         )
                 elif r.startswith('lte:'):
                     try:
                         if isinstance(value, (int, float)):
                             if value > float(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'lte_numeric', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'lte_numeric', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, str):
                             if len(value) > int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'lte_string', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'lte_string', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                         elif isinstance(value, list):
                             if len(value) > int(r.split(':')[1]):
                                 ValidatorService._add_error(
-                                    errors, field, 'lte_array', {'_attribute': field, '_value': r.split(':')[1]}
+                                    errors, field, 'lte_array', {'_attribute': field, 'value': r.split(':')[1]}
                                 )
                     except (ValueError, TypeError):
                         ValidatorService._add_error(
-                            errors, field, 'lte', {'_attribute': field, '_value': r.split(':')[1]}
+                            errors, field, 'lte', {'_attribute': field, 'value': r.split(':')[1]}
                         )
                 elif r.startswith('max:'):
                     max_val = int(r.split(':')[1])
@@ -701,7 +744,7 @@ class ValidatorService:
     def table_exists(table_name):
         """Check if the table exists in the database."""
         with connection.cursor() as cursor:
-            cursor.execute("SELECT EXISTS (SELECT 1 FROM information_schema.tables WHERE table_name = %s)", [table_name])
+            cursor.execute("SELECT EXISTS (SELECT 1 FROM information_schema.tables WHERE table_schema = DATABASE() AND table_name = %s)", [table_name])
             return cursor.fetchone()[0]
         
     @staticmethod
@@ -768,6 +811,29 @@ class ValidatorService:
                     if not ValidatorService.record_exists(table_name, column, item_value):
                         errors.append({'error_type': 'exists', 'tokens': {'_attribute': field_name}})
 
+                except ValueError as e:
+                    errors.append({'error_type': 'invalid_rule', 'tokens': {'message': str(e)}})
+            elif r.startswith('not_exist:') or r.startswith('not_exists:'):
+                try:
+                    parts = r.split(":", 1)[1].split(',')
+                    if len(parts) != 2:
+                        errors.append({'error_type': 'not_exist', 'tokens': {'_attribute': field_name}})
+                        continue
+
+                    table_name, column = parts
+                    # If item is a dict, take item[column]; otherwise use the item itself
+                    item_value = item.get(column) if isinstance(item, dict) else item
+
+                    if item_value is None or item_value == '':
+                        continue  # Skip validation for empty values
+
+                    if not ValidatorService.table_exists(table_name):
+                        errors.append({'error_type': 'not_exist', 'tokens': {'_attribute': "Table Not Found"}})
+                        continue
+
+                    if ValidatorService.record_exists(table_name, column, item_value):
+                        errors.append({'error_type': 'not_exist', 'tokens': {'_attribute': field_name}})
+
                 except ValueError as e:
                     errors.append({'error_type': 'invalid_rule', 'tokens': {'message': str(e)}})
         return errors
